@@ -70,6 +70,10 @@ struct acs *init_acs(void){
         case AC_ADSBONE:
             acs_adsbone_init(acs);
             break;
+        
+        case AC_AIRSCATTER_DK:
+            acs_airdk_init(acs);
+            break;
 
         default:
             log_addf(TRANSLATE("Unknown AS provider"));
@@ -113,6 +117,7 @@ void free_acs(struct acs *acs){
     acs_osn_free(acs);
     acs_file_free(acs);
     acs_adsbone_free(acs);
+    acs_airdk_free(acs);
 
     zg_free0(acs->sh.filename);
     g_free(acs->infolocqso.locator);
@@ -473,6 +478,7 @@ void plot_info_ac(struct subwin *sw, SDL_Surface *surface, struct ac *ac){
     if (ac){
         sw->ac_plotinfo = 1;
         color=z_makecol(21, 193, 106);
+        zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, "ICAO24: %s", ac->id); y += FONT_H + 4;
 
         if (cfg->ac_imperial){
             zsdl_printf(sw->screen, x, y, color, 0, ZFONT_TRANSP, "ASL: %5d ft", ac->feets); y += FONT_H + 4;
