@@ -25,7 +25,8 @@ struct qrv_item;
 enum acs_provider {
 	AC_OSN,
 	AC_FILE,
-	AC_ADSBONE
+	AC_ADSBONE,
+	AC_AIRSCATTER_DK
 };
 
 struct ac_result{
@@ -84,7 +85,7 @@ struct acs_shared{
     double infoctpqrb, infoctpqtf;
     int new_infoctp;
 
-	char tracked[AC_ICAOTYPE_MAXLEN];
+	char tracked[AC_ID_MAXLEN];
 	int rotnr;
 };
 
@@ -120,6 +121,10 @@ struct acs{
 	struct zhttp* adsbone_http;
 	char* adsbone_http_error;
 
+	int airdk_http_timer;
+	struct zhttp* airdk_http;
+	char* airdk_http_error;
+
 
 #ifdef Z_HAVE_SDL
 	void (*plot_info)(struct subwin* sw, SDL_Rect* area, struct acs* acs);
@@ -207,4 +212,15 @@ void acs_adsbone_load_from_main_thread(struct acs* acs, const char* data);
 void acs_adsbone_plot_info(struct subwin* sw, SDL_Rect* area, struct acs* acs);
 #endif
 
+//airscatter.dk
+int acs_airdk_init(struct acs* acs);
+void acs_airdk_free(struct acs* acs);
+void acs_airdk_http_timer(void* arg);
+void acs_airdk_downloaded_callback(struct zhttp* http);
+void acs_airdk_load_from_main_thread(struct acs* acs, const char* data);
+#ifdef Z_HAVE_SDL
+void acs_airdk_plot_info(struct subwin* sw, SDL_Rect* area, struct acs* acs);
+#endif
+
+
 #endif
