@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -57,7 +57,7 @@ static void device_info(GString *gs, int card, int pcm_device, snd_pcm_stream_t
    // if (err<0) goto x1;
     err=snd_pcm_hw_params_get_channels_max(hwparams, &channels_max);
    // if (err<0) goto x1;
-    g_string_sprintfa(gs, "        channels=%d .. %d .. %d\n", channels_min, channels, channels_max);
+    g_string_append_printf(gs, "        channels=%d .. %d .. %d\n", channels_min, channels, channels_max);
 //x1:;
     
     unsigned int rate_min, rate, rate_max;
@@ -68,7 +68,7 @@ static void device_info(GString *gs, int card, int pcm_device, snd_pcm_stream_t
     if (err<0) goto x2;
     err=snd_pcm_hw_params_get_rate_max(hwparams, &rate_max, &dir_max);
     if (err<0) goto x2;
-    g_string_sprintfa(gs, "        rate=%d .. %d .. %d\n", rate_min, rate, rate_max);
+    g_string_append_printf(gs, "        rate=%d .. %d .. %d\n", rate_min, rate, rate_max);
 x2:
 
     if (dir == SND_PCM_STREAM_CAPTURE){
@@ -82,7 +82,7 @@ x2:
             goto x3c;
         }
         mixer_chip=snd_ctl_card_info_get_mixername(hw_info);
-        g_string_sprintfa(gs, "        mixer chip=%s\n", mixer_chip);
+        g_string_append_printf(gs, "        mixer chip=%s\n", mixer_chip);
         snd_ctl_close(ctl_handle);
 
 x3c:        
@@ -95,7 +95,7 @@ x3c:
         err=snd_mixer_load(mixer_handle);
         if (err<0) goto x3;
 
-        g_string_sprintfa(gs, "        elements=");
+        g_string_append_printf(gs, "        elements=");
         for (elem=snd_mixer_first_elem(mixer_handle);
              elem;
              elem=snd_mixer_elem_next(elem)){
@@ -106,11 +106,11 @@ x3c:
             if (err<0) goto x3;
             
             if (sw)
-                g_string_sprintfa(gs, "[%s] ", snd_mixer_selem_get_name(elem));
+                g_string_append_printf(gs, "[%s] ", snd_mixer_selem_get_name(elem));
             else
-                g_string_sprintfa(gs, "'%s' ", snd_mixer_selem_get_name(elem));
+                g_string_append_printf(gs, "'%s' ", snd_mixer_selem_get_name(elem));
         }
-        g_string_sprintfa(gs, "\n");
+        g_string_append_printf(gs, "\n");
 
 x3:
         snd_mixer_close(mixer_handle);
@@ -130,12 +130,12 @@ static void card_info(GString *gs, int card){
     char dev[256];
     snd_pcm_info_t *pcm_info;
 
-    g_string_sprintfa(gs, "card hw:%d ",card);
+    g_string_append_printf(gs, "card hw:%d ",card);
 
     if (snd_card_get_name(card, &name)==0){
-        g_string_sprintfa(gs, "%s", name);
+        g_string_append_printf(gs, "%s", name);
     }
-    g_string_sprintfa(gs, "\n");                
+    g_string_append_printf(gs, "\n");                
 
     sprintf(dev,"hw:%d", card);
     snd_ctl_open(&ctl, dev, 0);
@@ -153,7 +153,7 @@ static void card_info(GString *gs, int card){
         
         if (snd_ctl_pcm_info(ctl, pcm_info)<0) continue;
         
-        g_string_sprintfa(gs, "    playback hw:%d,%d %s\n", card, pcm_device, snd_pcm_info_get_name(pcm_info)); 
+        g_string_append_printf(gs, "    playback hw:%d,%d %s\n", card, pcm_device, snd_pcm_info_get_name(pcm_info)); 
         device_info(gs, card, pcm_device, SND_PCM_STREAM_PLAYBACK);
     }
     
@@ -168,7 +168,7 @@ static void card_info(GString *gs, int card){
         
         if (snd_ctl_pcm_info(ctl, pcm_info)<0) continue;
         
-        g_string_sprintfa(gs, "    capture  hw:%d,%d %s\n", card, pcm_device, snd_pcm_info_get_name(pcm_info)); 
+        g_string_append_printf(gs, "    capture  hw:%d,%d %s\n", card, pcm_device, snd_pcm_info_get_name(pcm_info)); 
         device_info(gs, card, pcm_device, SND_PCM_STREAM_CAPTURE);
     }
 }
@@ -176,7 +176,7 @@ static void card_info(GString *gs, int card){
 void alsa_info(GString *gs){
     int card;
     
-    g_string_sprintfa(gs, "\n  alsa_info:\n");
+    g_string_append_printf(gs, "\n  alsa_info:\n");
     card=-1;
     snd_card_next(&card);
     while(card>-1){
@@ -184,7 +184,7 @@ void alsa_info(GString *gs){
         snd_card_next(&card);
     }
     
-    g_string_sprintfa(gs, "\n");
+    g_string_append_printf(gs, "\n");
 }
 
 
