@@ -1,6 +1,6 @@
 /*
     chart - chart compare of points progress
-    Copyright (C) 2011-2015 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2023 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -23,7 +23,7 @@
 #include "menu.h"
 #include "tsdl.h"
 #include "session.h"
-
+#include "terminal.h"
 
 #define TOP 20
 #define BOTTOM (FONT_H + 4)
@@ -519,13 +519,15 @@ int sw_chart_load_file(struct subwin *sw, char *filename, int quiet){
         }
     }
     while(strncasecmp(gs->str, "[qsorecords", 11)!=0){
+        items = NULL;
         if (zfile_fgets(gs, f, 0) == NULL) goto x;
         if (strncasecmp(gs->str, "qso", 3) == 0){
             items = g_strsplit_set(gs->str, "=;", 0);
             for (j = 0; j <= 4; j++) if (!items[j]) goto bado;
             g_hash_table_insert(hash, g_strdup(items[0]), g_strdup(items[2]));
         }
-bado:;
+    bado:;
+        g_strfreev(items);
     }
     v = 0;
     while(zfile_fgets(gs, f, 0) != NULL){
@@ -551,7 +553,8 @@ bado:;
         q->value = v;
         g_ptr_array_add(b->chqsos, q);
         //dbg("%d %d %d\n", q->time, q->pts, q->value);
-badq:;
+    badq:;
+        g_strfreev(items);
     }
     fclose(f);
 
@@ -594,7 +597,7 @@ int sw_chart_recalc_extremes(struct subwin *sw, struct band *band){
             if (t < sw->mint) sw->mint = t;
             if (t > sw->maxt) sw->maxt = t;
             if (v < sw->minv) sw->minv = v;
-            if (v > sw->maxv) sw->maxv = v;
+            if (v > sw->maxv) sw->maxv = v * 1.1;
         }
     }
     for (i = 0; i < sw->chbands->len; i++){
@@ -708,13 +711,12 @@ void chart_clear_all(){
     zg_ptr_array_foreach(struct subwin *, subwin, gses->subwins){
         //dbg("title=%s\n", subwin->title);
         if (!subwin->chbands) continue;
-        {
-            zg_ptr_array_foreachback(struct chband*, chband, subwin->chbands){
-                    
-              //  dbg("free\n");
-                sw_chart_free_band(chband);
-                g_ptr_array_remove_index(subwin->chbands, chband_i);
-            }
+     
+        int i;
+        for (i = subwin->chbands->len - 1; i >= 0; i--) {
+            struct chband* chband = (struct chband*)g_ptr_array_index(subwin->chbands, i);
+            sw_chart_free_band(chband);
+            g_ptr_array_remove_index(subwin->chbands, i);
         }
     }
     redraw_later();
