@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2006  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2023  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -189,6 +189,20 @@ void wkd_tmpqso(struct band *band, enum wt_type type, gchar *str){
     g_free(c);
 }
 
+void wkd_send_all(struct band *b){
+	wkd_tmpqso(b, WT_CALLSIGN, b->tmpqsos[0].callsign);
+	wkd_tmpqso(b, WT_RSTS, b->tmpqsos[0].rsts);
+	wkd_tmpqso(b, WT_RSTR, b->tmpqsos[0].rstr);
+	wkd_tmpqso(b, WT_QSONRS, b->tmpqsos[0].qsonrs);
+	wkd_tmpqso(b, WT_QSONRR, b->tmpqsos[0].qsonrr);
+	wkd_tmpqso(b, WT_EXC, b->tmpqsos[0].exc);
+	wkd_tmpqso(b, WT_LOCATOR, b->tmpqsos[0].locator);
+	if (b == aband) wkd_tmpqso(b, WT_BAND, b->pband);
+	wkd_tmpqso(b, WT_OPERATOR, b->operator_);
+	peer_tx(b, gses->last_cq_timer_id>0 ? 2 : gses->tx);
+	send_inputline(b);
+}
+
 void peer_tx(struct band *band, int tx){
     gchar *c;
     if (!ctest || !band) return;
@@ -313,7 +327,7 @@ struct spypeer *get_spypeer_by_peerid(GPtrArray *sps, gchar *peerid, char bandch
         struct spypeer *sp;
         sp=(struct spypeer *)g_ptr_array_index(sps, i);
         if (strcmp(sp->peerid, peerid)) continue;
-        if (sp->bandchar != bandchar) continue;
+        if (sp->bandchar != bandchar && sp->bandchar != '*') continue;
         return sp;
     }
     return NULL;
@@ -371,20 +385,25 @@ void spypeer_add(char *peerid, char bandchar, int send_request){
     //dbg("spypeer_add: peerid=%s bandchar=%c pband=%s\n", peerid, bandchar, b->pband);
 	sp = init_spypeer(ctest->spypeers, peerid, bandchar);
 
-	if (send_request) spypeer_send_request(sp);
+	if (send_request) spypeer_send_request(sp, '\0');
 	
 }
 
-void spypeer_send_request(struct spypeer *sp){
-    struct band *b;
-    gchar *c;
+void spypeer_send_request(struct spypeer *sp, char bandchar){
 
-	b = find_band_by_bandchar(sp->bandchar);
-    if (!b){
-        dbg("band %c not found\n", sp->bandchar);
-        return;
-    }
-	c = g_strdup_printf("RT %s;%s\n", b->pband, sp->peerid);
+	if (bandchar == '\0') bandchar = sp->bandchar;
+
+	gchar *c;
+	if (bandchar == '*' && aband){
+		c = g_strdup_printf("RT *;%s\n", sp->peerid);
+	}else{
+		struct band *b = find_band_by_bandchar(bandchar);
+		if (!b){
+			dbg("band %c not found\n", sp->bandchar);
+			return;
+		}
+		c = g_strdup_printf("RT %s;%s\n", b->pband, sp->peerid);
+	}
     rel_write_all(c);
     g_free(c);
 }
@@ -395,7 +414,7 @@ void spypeer_send_requests(){
         struct spypeer *sp;
 
         sp = (struct spypeer *)g_ptr_array_index(ctest->spypeers, i);
-		spypeer_send_request(sp);
+		spypeer_send_request(sp, '\0');
     }
 }
 
