@@ -15,6 +15,7 @@
 #include "control.h"
 #include "cwdaemon.h"
 #include "davac4.h"
+#include "davac5.h"
 #include "dsp.h"
 #include "edi.h"
 #include "fifo.h"
@@ -128,6 +129,24 @@ struct cwdaemon *init_cwdaemon(void){
 #else			
             log_addf(VTEXT(T_NO_DAVAC4_SUPPORT));
             dbg("Support for davac4 isn't compiled in, check for libftdi");
+#endif
+            break;
+        case CWD_DAVAC5:
+#ifdef HAVE_HIDAPI
+            cwda->init = davac5_init;
+            cwda->free = davac5_free;
+            cwda->reset = davac5_reset;
+            cwda->text = cwdaemon_text;
+            cwda->sspeed = cwdaemon_speed;
+            cwda->sweight = cwdaemon_weight;
+            cwda->cw = davac5_cw;
+            cwda->ptt = davac5_ptt;
+            cwda->ssbway = davac5_ssbway;
+            cwda->back = cwdaemon_back;
+            MUTEX_INIT(cwda->hid);
+#else			
+            log_addf(VTEXT(T_NO_DAVAC5_SUPPORT));
+            dbg("Support for davac5 isn't compiled in, check for hidapi");
 #endif
             break;
             
@@ -203,7 +222,8 @@ struct cwdaemon *init_cwdaemon(void){
     cwda->code=g_string_sized_new(100);
     cwda->played=g_string_sized_new(100);
 	cwda->thread=g_thread_try_new("cwdaemon", cwdaemon_thread_func, (gpointer)cwda, NULL);
-    if (cwda->init) cwda->init(cwda);
+	if (cwda->init) cwda->init(cwda);
+	if (cwda->reset) cwda->reset(cwda);
 /*    cwdaemon_cw_string(cwda, "cq cq de ok1zia"); */
     /*cwdaemon_cw_string(cwda, "cq"); */
     return cwda;
