@@ -989,6 +989,9 @@ void call_info(void *arg){
             gmtime_r(&qi->kst_time, &utc);
             g_string_append_printf(gs, " %2d:%02d", utc.tm_hour, utc.tm_min);
         }
+		if (qi->text != NULL){
+			g_string_append_printf(gs, "  %s", qi->text);
+		}
     }else{
         g_string_append(gs, VTEXT(T_0X_NOT_IN_DB));
     }
