@@ -22,8 +22,10 @@
 #include "map.h"
 #include "namedb.h"
 #include "net.h"
+#include "oct8tor.h"
 #include "qrvdb.h"
 #include "qsodb.h"
+#include "rotar.h"
 #include "rain.h"
 #include "session.h"
 #include "sked.h"
@@ -269,6 +271,7 @@ static int write_edi_remarks(struct band *b, struct config_band *confb, FILE *f)
     g_string_append_printf(gs, "readonly=%d\r\n", b->readonly);
     g_string_append_printf(gs, "saveid=%d\r\n", b->saveid);
 	g_string_append_printf(gs, "skedqrg=%s\r\n", b->skedqrg);
+	g_string_append_printf(gs, "qrg=%1.0f\r\n", b->qrg);
 
     for (i=0; i< b->qsos->len; i++){
         q = get_qso(b, i); 
@@ -701,6 +704,10 @@ static gchar *load_edi_remarks_until(FILE *f, gchar *until){
 }
 
 
+static void array_free(gpointer item){
+    gchar **a = (gchar **)item;
+    g_strfreev(a);
+}
 
 static GPtrArray *load_edi_qsos_until(FILE *f, gchar *until){
     GString *gs;
@@ -711,7 +718,7 @@ static GPtrArray *load_edi_qsos_until(FILE *f, gchar *until){
     
     gs=g_string_new("");
     
-	array = g_ptr_array_new();
+	array = g_ptr_array_new_with_free_func(array_free);
  
     while( (c = zfile_fgets(gs, f, 0)) != NULL){
 /*        dbg("load_edi_qsos_unti: '%s'\n", c);*/
@@ -764,7 +771,7 @@ static void destroy_string_hash(GHashTable *hash){
 
 
 static void add_qsos_from_mem(struct band *b, GHashTable *hash, GPtrArray *qsos, const gchar *date){
-    gchar **items;
+    gchar **items, **items2;
     int i, j;
     gchar *c, *add;
     struct qso *q;
@@ -794,7 +801,7 @@ static void add_qsos_from_mem(struct band *b, GHashTable *hash, GPtrArray *qsos,
         q->exc      = g_strdup(items[8]);
         q->locator  = g_strdup(items[9]);
         
-		g_strfreev(items);
+		//g_strfreev(items); freed after for
 
         c = g_strdup_printf("qso%d", i);
         add = (char *)g_hash_table_lookup(hash, c);
@@ -806,52 +813,52 @@ static void add_qsos_from_mem(struct band *b, GHashTable *hash, GPtrArray *qsos,
                                 "%s;%s;%d;",    
                     gnet->myid, fixsemi(b->operator_), (int)now, "",
                     century, "", -1);
-            items = g_strsplit(add, ";", 0);
+            items2 = g_strsplit(add, ";", 0);
             g_free(add);
         }else{
-            items = g_strsplit(add, ";", 0);
+            items2 = g_strsplit(add, ";", 0);
         }
        
-        for (j=0;j<=4;j++) if (!items[j]) goto x;
+        for (j=0;j<=4;j++) if (!items2[j]) goto x;
         
-        q->source    = g_strdup(items[0]);
-        q->operator_ = g_strdup(items[1]);
+        q->source    = g_strdup(items2[0]);
+        q->operator_ = g_strdup(items2[1]);
         fixsemi(q->operator_);
-        q->stamp    = atoi(items[2]);
-        if (!items[5]){
+        q->stamp    = atoi(items2[2]);
+        if (!items2[5]){
             q->remark   = g_strdup("");
         }else{
-            q->remark   = g_strdup(items[5]);
+            q->remark   = g_strdup(items2[5]);
         }
 
-        if (q->error && *items[3]){
+        if (q->error && *items2[3]){
             g_free(q->callsign);
-            q->callsign = g_strdup(items[3]);
+            q->callsign = g_strdup(items2[3]);
         }
         
         
         c = q->date_str;
-        if (strlen(c)>2 && items[4]) {
-            q->date_str = g_strdup_printf("%s%s", items[4], c+2);
+        if (strlen(c)>2 && items2[4]) {
+            q->date_str = g_strdup_printf("%s%s", items2[4], c+2);
             g_free(c); 
         }
         
 
-        if (items[6]){
-            q->ser_id=atoi(items[6]);
+        if (items2[6]){
+            q->ser_id=atoi(items2[6]);
             edi_serid_used=1;
         }else{
             q->ser_id=-1; /* filled in add_qso_to_index and rewritten after loop. only for compatibility */
         }
 
-        if (items[6] && items[7]){
-            q->qrg = atof(items[7]);
+        if (items2[6] && items2[7]){
+            q->qrg = atof(items2[7]);
         }else{
             q->qrg = 0.0; 
         }
 
-		if (items[6] && items[7] && items[8]){
-			q->phase = atoi(items[8]);
+		if (items2[6] && items2[7] && items2[8]){
+			q->phase = atoi(items2[8]);
 			if (q->phase > ctest->phase) 
 				ctest->phase = q->phase;
 		}
@@ -859,7 +866,7 @@ static void add_qsos_from_mem(struct band *b, GHashTable *hash, GPtrArray *qsos,
 			q->phase = 1;
 		}
         
-        g_strfreev(items);
+        g_strfreev(items2);
         compute_qrbqtf(q);
         add_qso(b, q);
         update_stats(b, b->stats, q);
@@ -980,7 +987,6 @@ void load_contest_edi(const gchar *date, int edi){
     char *ext, *c;
     FILE *f, *lockfile,*logfile;
     GHashTable *hash;
-    GPtrArray *qsos;
     struct band *b;
     static char ss[1024];
     gint saveid=-1;
@@ -1078,7 +1084,7 @@ void load_contest_edi(const gchar *date, int edi){
             hash = load_edi_until(f, NULL, "^\\[remarks\\]");
             remarks = load_edi_remarks_until(f, "^\\[qsorecords");
         }
-        qsos = load_edi_qsos_until(f, "^\\[end;");
+        GPtrArray *qsos = load_edi_qsos_until(f, "^\\[end;");
         
         fclose(f);
         
@@ -1114,7 +1120,6 @@ destroy:;
 			update_hw();
             maps_reload();
 			maps_update_showwwls();
-            chart_reload();
 #ifdef Z_HAVE_SDL
 			rain_reload();
 #endif
@@ -1185,6 +1190,15 @@ destroy:;
 					process_input(b, t->str, 0);
 					g_string_free(t, TRUE);
 
+					c = g_strdup_printf("%s'", items[4]);
+					process_input(b, c, 0);
+					g_free(c);
+
+					c = g_strdup_printf("%s,", items[6]);
+					process_input(b, c, 0);
+					g_free(c);
+
+
 					g_strfreev(items);
 					
                     process_input(b, "", 0);
@@ -1201,7 +1215,7 @@ destroy:;
         }
         fclose(f);
         g_string_free(gs, 1);
-        
+        //g_ptr_array_free(qsos, TRUE);
     }
     
     if (!ctest) {
@@ -1297,7 +1311,13 @@ destroy:;
             progress(VTEXT(T_ACTIVATING_BAND), b->bandname);
             activate_band(b); /* b==NULL is handled by function */
         }
-    }
+	}
+	chart_reload();
+
+#ifdef OCT8TOR
+	struct config_band *cb = get_config_band_by_bandchar(aband->bandchar);
+	oct8tor_send_band(goct8tor, cb->adifband);
+#endif
 
 	progress(VTEXT(T_UPDATING_WKD));
     qrv_recalc_wkd(qrv);
@@ -1355,7 +1375,7 @@ void import_edi(void *xxx, char *filename){
     add_qsos_from_mem(band, hash, qsos, ctest->cdate);
 destroy:;    
     destroy_string_hash(hash);  
-    zg_ptr_array_free_all(qsos);  
+    //zg_ptr_array_free_all(qsos);  
     redraw_later();
 }
 
