@@ -28,17 +28,19 @@
                 if (c2) {g_free(c2); c2=NULL;}\
                 if (c3) {g_free(c3); c3=NULL;}
 
-void draw_inputln(struct inputln *il, int sel){
+void draw_inputln(struct inputln *il, int selx){
+	unsigned color = COL_INV;
+	if (il->is_susp) color = (COL_DARKRED << 3) | COL_WHITE;
 
     /*dbg("draw_inputln (%d,%d)\n",il->x,il->y);*/
     if (il->vpos + il->l <= il->cpos) il->vpos = il->cpos - il->l + 1;
     if (il->vpos > il->cpos) il->vpos = il->cpos;
     if (il->vpos < 0) il->vpos = 0;
-    fill_area(il->x, il->y, il->l, 1, COL_INV);
+	fill_area(il->x, il->y, il->l, 1, color);
     
-    print_text(il->x, il->y, strlen(il->cdata + il->vpos) <= il->l ? strlen(il->cdata + il->vpos) : il->l, il->cdata + il->vpos, COL_INV);
+	print_text(il->x, il->y, strlen(il->cdata + il->vpos) <= il->l ? strlen(il->cdata + il->vpos) : il->l, il->cdata + il->vpos, color);
 #ifdef Z_HAVE_SDL
-	if (sdl && cfg->usetouch) print_text(il->x + il->l, il->y, 1, "\x19", COL_INV);
+	if (sdl && cfg->usetouch) print_text(il->x + il->l, il->y, 1, "\x19", color);
 #endif
 
 
