@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2023  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -131,7 +131,7 @@ static struct default_kb default_main_keymap[] = {
     { ACT_FIND_NEXT_BACK, 'N', 0 },
     { ACT_FIND_NEXT, 'n', 0 },
 	{ ACT_FULLSCREEN, KBD_F11, KBD_CTRL },
-    { ACT_GRAB_BAND, 'g', KBD_ALT },
+   // { ACT_GRAB_BAND, 'g', KBD_ALT },
     { ACT_HOME, KBD_HOME, 0 },
     { ACT_INSERT, KBD_INS, 0 },
     { ACT_LEFT, KBD_LEFT, 0 },
@@ -147,7 +147,8 @@ static struct default_kb default_main_keymap[] = {
 	{ ACT_QUIT, KBD_F4, KBD_ALT },
     { ACT_REALLYQUIT, 'q', KBD_ALT },
     { ACT_RIGHT, KBD_RIGHT, 0 },
-    { ACT_ROTAR, 'r', KBD_ALT },
+	{ ACT_ROTAR, 'r', KBD_ALT },
+	{ ACT_ROTAR_STOP, 'S', KBD_CTRL },
 	{ ACT_RUNMODE, 'R', KBD_CTRL },
     { ACT_RX, KBD_ESC, 0 },
     { ACT_RXTX, KBD_TAB, 0 },
