@@ -86,9 +86,7 @@ int sw_kst_kbd_func(struct subwin *sw, struct event *ev, int fw){
                 return 1;
             case KBD_DOWN:
                 if (sw->side_bott) return 1;
-                //size = g_hash_table_size(sw->kstusers);
                 sw->kst_offset += 1;
-                //if (sw->kst_offset > size - 3) sw->kst_offset = size - 3;
                 redraw_later();
                 return 1;
             case KBD_PGUP:
@@ -307,7 +305,6 @@ int sw_kst_mouse_func(struct subwin *sw, struct event *ev, int fw){
                 sw->kst_offset += 3;
                 size = g_hash_table_size(sw->kstusers);
                 if (sw->kst_offset > size - 3) sw->kst_offset = size - 3;
-                //dbg("kst_offset=%d\n", sw->kst_offset);
                 redraw_later();
                 return 1;
             }
@@ -332,12 +329,16 @@ void sw_kst_call_choosen(void *itdata, void *menudata){
 void kst_right_mouse_2(struct subwin *sw){
 	int items = 0;
 	struct menu_item *mi = new_menu(1);
+
+	
+
 	mi->rtext = sw->callunder;
 	if (!cfg->usetouch){
 		add_to_menu(&mi, CTEXT(T_MISTAKE), "", CTEXT(T_HK_MISTAKE), sw_kst_nothing, NULL, 0); items++;
 	}
 	add_to_menu(&mi, CTEXT(T_ASK_FOR_SKED), "", CTEXT(T_HK_ASK_FOR_SKED), sw_kst_ask_sked, GINT_TO_POINTER(1), 0); items++;
 	add_to_menu(&mi, CTEXT(T_ASK_FOR_SKED_B), "", CTEXT(T_HK_ASK_FOR_SKED_B), sw_kst_ask_sked, GINT_TO_POINTER(2), 0); items++;
+	add_to_menu(&mi, TRANSLATE("Sked - ant is to you"), "", "T", sw_kst_ask_sked, GINT_TO_POINTER(3), 0); items++;
 	add_to_menu(&mi, CTEXT(T_SELECT), "", CTEXT(T_HK_SELECT), sw_kst_select, NULL, 0); items++;
 	add_to_menu(&mi, CTEXT(T_HIDE), "", CTEXT(T_HK_HIDE), sw_kst_hide, NULL, 0); items++;
 	add_to_menu(&mi, CTEXT(T_MESSAGE), "", CTEXT(T_HK_MESSAGE), sw_kst_message, NULL, 0); items++;
@@ -378,7 +379,7 @@ static void sw_kst_draw(gpointer key, gpointer value, gpointer user_data){
     //z_get_raw_call(raw, (char*)call);
     color = sw_kst_color(call);
 
-    if (!g_hash_table_lookup_extended(sw->kstoldusers, call, NULL, NULL)) {
+    if (qi->new_on_kst) {
         color |= COL(1 * 8); // new call red background
         clip_printf(sw, sw->w + 1, sw->kst_y, color, "                     ");
     }
@@ -544,20 +545,6 @@ found:;
         //qi->ac_drawn = 0;
         qi->ac_start = (time_t)0;
     }
-    //}else{
-    //  GPtrArray *arr = g_ptr_array_new();
-    //  int i;
-    //
-    //    sw->kst_y = 0;
-    //    g_hash_table_foreach(sw->kstusers, sw_kst_array_add, arr);
-    //  zg_ptr_array_qsort (arr, z_compare_string);
-    //  for (i = sw->kst_offset; i < arr->len; i++){
-    //      char *call = (char *)g_ptr_array_index(arr, i);
-    //      sw_kst_draw(call, g_hash_table_lookup(sw->kstusers, call), sw);
-    //  }
-    //
-    //  g_ptr_array_free(arr, TRUE);
-    //}
     
 #ifdef Z_HAVE_SDL
     if (sw->screen != NULL && gacs != NULL){
@@ -1038,9 +1025,9 @@ void sw_kst_append_qrg(GString *gs){
     if (!full_qrg){ // not full qrg information
         if (aband->qrg_min < 20000000){
             struct config_band *confb = get_config_band_by_bandchar(aband->bandchar);
-            if (confb) g_string_append_printf(gs, "on %s ", confb->adifband);
+            if (confb) g_string_append_printf(gs, "%s ", confb->adifband);
         }else{
-            g_string_append_printf(gs, "on %s ", aband->pband);
+            g_string_append_printf(gs, "%s ", aband->pband);
         }
     }
 }
@@ -1051,11 +1038,12 @@ void sw_kst_ask_sked(void *itdata, void *menudata){
     char *name;
     struct subwin *sw = (struct subwin*)menudata;
     GString *gs = g_string_sized_new(256);
+	int type = 0;
+	if (itdata != NULL) type = GPOINTER_TO_INT(itdata);
 
-    
     g_string_append_printf(gs, "/cq %s ", sw->callunder);
     
-    if (itdata != NULL && GPOINTER_TO_INT(itdata) == 1){
+    if (type == 1){
         now = time(&now);
         localtime_r(&now, &tm);
         
@@ -1066,17 +1054,20 @@ void sw_kst_ask_sked(void *itdata, void *menudata){
         name = find_name_by_call(namedb, sw->callunder);
         if (name) g_string_append_printf(gs, "%s, ", name);
 
-        g_string_append(gs, "PSE sked ");
-    }else{
+		g_string_append(gs, "PSE sked on ");
+	}
+	else if (type == 3) {
+		g_string_append_printf(gs, "ANT is now in your direction on ");
+	}else{ // 2 or default
         g_string_append(gs, "I am calling you on ");
     }
 
     sw_kst_append_qrg(gs);
 
-    if (itdata != NULL && GPOINTER_TO_INT(itdata) == 1)
-        g_string_append_printf(gs, "OK?");
+	if (type == 1 || type == 2)
+        g_string_append_printf(gs, " OK?");
     else
-        g_string_append_printf(gs, "and have ANT in your direction. Could you check it?");
+        g_string_append_printf(gs, ". Could you check it?");
     
     askkst(sw->il, gs->str);
 
@@ -1278,18 +1269,27 @@ int kst_read_line(struct subwin *sw, char *line){
 		}
     }
 
-    if (regmatch(line,"^([A-Z0-9\\(\\)\\/\\ -]{14})\\ ([A-R]{2}[0-9]{2}[A-X]{2})\\ (([^\\ ]{1,}).*)", &c1, &c2, &c3, &c4, &c5, NULL)==0){
+	//if (regmatch(line, "^([A-Z0-9\\(\\)\\/\\ -]{14})\\ ([A-R]{2}[0-9]{2}[A-X]{2})\\ (([^\\ ]{1,}).*)", &c1, &c2, &c3, &c4, &c5, NULL) == 0){
+	if (regmatch(line, "^([A-Z0-9\\(\\)\\/\\ -]{14,16})\\ ([A-R]{2}[0-9]{2}[A-X]{2})\\ (([^\\ ]{1,}).*)", &c1, &c2, &c3, &c4, &c5, NULL) == 0){
         time_t now;
         struct tm gmt;
         int stamp;
         double qrb, qtf;
 
+		//if (strstr(line, "9A2SB") != NULL){
+		//	int a = 0;
+		//}
+
         call = c2;
         z_str_uc(call);
         z_strip_from(call, ' ');
         z_strip_from(call, ')');
         z_strip_from(call, '-');
-        if (call[0] == '(') call++;
+		if (call[0] == '(') {
+			zg_free0(c1); zg_free0(c2); zg_free0(c3); zg_free0(c4);	zg_free0(c5);
+			return 1; // skip
+		}
+
         wwl = c3;
         z_str_uc(wwl);
         
@@ -1317,7 +1317,10 @@ int kst_read_line(struct subwin *sw, char *line){
             qi = (struct qrv_item *)g_hash_table_lookup(qrv->hash, call/*raw*/);
             //dbg("add %s   qi=%p\n", call, qi);
             // qi can be NULL
-            g_hash_table_insert(sw->kstusers, g_strdup(call), qi);
+            g_hash_table_insert(sw->tmpkstusers, g_strdup(call), qi);
+			if (!sw->first_shus && !g_hash_table_lookup_extended(sw->kstusers, call, NULL, NULL)) {
+				qi->new_on_kst = 1;
+			}
             if (sw->shus == 1) ret = 1; // skip
         }
     }
@@ -1380,9 +1383,16 @@ void kst_shus(struct subwin *sw, int shus){
     //log_addf("kst_shus(%d)", sw->shus);
     //dbg("1 users=%d oldusers=%d\n", g_hash_table_size(sw->kstusers), g_hash_table_size(sw->kstoldusers)); 
 
-    g_hash_table_destroy(sw->kstoldusers);
-    sw->kstoldusers = sw->kstusers;
-    sw->kstusers = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL); // 2x
+    g_hash_table_destroy(sw->tmpkstusers);
+	sw->tmpkstusers = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, NULL); // 2x. really?
+
+	if (qrv != NULL && qrv->qrvs != NULL){
+		int i;
+		for (i = 0; i < qrv->qrvs->len; i++){
+			struct qrv_item *qi = (struct qrv_item *)z_ptr_array_index(qrv->qrvs, i);
+			qi->new_on_kst = 0;
+		}
+	}
     //dbg("2 users=%d oldusers=%d\n", g_hash_table_size(sw->kstusers), g_hash_table_size(sw->kstoldusers)); 
 
     //dbg("/sh us\n");
@@ -1390,25 +1400,27 @@ void kst_shus(struct subwin *sw, int shus){
 
 static void kst_copy_users(gpointer key, gpointer value, gpointer user_data){
     struct subwin *sw = (struct subwin*)user_data;
-    g_hash_table_insert(sw->kstoldusers, g_strdup(key), g_strdup(value));
+    g_hash_table_insert(sw->kstusers, g_strdup(key), g_strdup(value));
 }
 
 void kst_end_shus(struct subwin *sw){
     if (!sw->shus) return;
 
     //dbg("/sh us end, users=%d oldusers=%d\n", g_hash_table_size(sw->kstusers), g_hash_table_size(sw->kstoldusers)); 
-    //log_addf("/sh us end, users=%d oldusers=%d", g_hash_table_size(sw->kstusers), g_hash_table_size(sw->kstoldusers)); 
+	//log_addf("/sh us end, tmpkstusers=%d -> kstusers=%d", g_hash_table_size(sw->tmpkstusers), g_hash_table_size(sw->kstusers));
     sw->shus = 0;
-    if (sw->first_shus){
-        sw->first_shus = 0;
-        g_hash_table_remove_all(sw->kstoldusers);
-        g_hash_table_foreach(sw->kstusers, kst_copy_users, sw);
-    }
+    if (sw->first_shus) sw->first_shus = 0;
+
+	if (g_hash_table_size(sw->tmpkstusers) > 0){
+		g_hash_table_remove_all(sw->kstusers);
+		g_hash_table_foreach(sw->tmpkstusers, kst_copy_users, sw);
+	}
+	//log_addf("/sh us end, kstusers=%d", g_hash_table_size(sw->tmpkstusers));
 }
 
 void kst_clear_users(struct subwin *sw){
     g_hash_table_remove_all(sw->kstusers);
-    if (sw->kstoldusers) g_hash_table_remove_all(sw->kstoldusers);
+	if (sw->tmpkstusers) g_hash_table_remove_all(sw->tmpkstusers);
 }
 
 int kst_user_skip(struct subwin *sw, const char *call){
