@@ -19,6 +19,7 @@
 #include "cwdaemon.h"
 #include "cwdb.h"
 #include "davac4.h"
+#include "davac5.h"
 #include "dsp.h"
 #include "dwdb.h"
 #include "dxc.h"
@@ -26,7 +27,6 @@
 #include "excdb.h"
 #include "fft.h"
 #include "fifo.h"
-#include "hdkeyb.h"
 #include "httpd.h"
 #include "kbdbind.h"
 #include "kbd.h"
@@ -367,7 +367,9 @@ static void main_msg_handler(struct zselect *zsel, int n, char **items){
         return;
     }
     
-    if (!items[1]) zinternal("main_msg_handler bad format 2 (%s)", items[0]);
+	if (!items[1]) {
+		zinternal("main_msg_handler bad format 2 (%s)", items[0]);
+	}
 #if defined(HAVE_SNDFILE) || defined(Z_ANDROID)
     if (strcmp(items[0], "SSBP")==0){
         ssbd_play_read_handler(gssbd, items[1]);
@@ -398,11 +400,11 @@ static void main_msg_handler(struct zselect *zsel, int n, char **items){
         rotar_read_handler(n, items);
         return;
     }
-#ifdef Z_HAVE_LIBFTDI
-    if (strcmp(items[0], "HD")==0){
-        hdkeyb_read_handler(n, items);
-        return;
-    }
+#ifdef OCT8TOR
+	if (strcmp(items[0], "OCT") == 0){
+		oct8tor_read_handler(n, items);
+		return;
+	}
 #endif
 	if (strcmp(items[0], "ZFILEDLG")==0){
 		zfiledlg_read_handler(n, items);
@@ -453,7 +455,22 @@ void info(GString *gs){
 #endif
 #endif        
 #ifdef Z_HAVE_LIBFTDI
+	if (gses != NULL) {
+		free_cwdaemon(cwda);
+		free_rotars();
+	}
     usb_info(gs);
+#endif
+#ifdef HAVE_HIDAPI
+    hid_info(gs);
+#endif
+#ifdef Z_HAVE_LIBFTDI
+	if (gses != NULL) {
+		cwda = init_cwdaemon();
+		init_rotars();
+		progress(NULL);
+		redraw_later();
+	}
 #endif
     iface_info(gs);
     bat_info(gs);
@@ -570,11 +587,11 @@ static void init(void)
 	//zjson_test();
 
 	dbg("Tucnak-%s %s svn %s (%s) pid=%d user=%s\n", Z_PLATFORM, PACKAGE_VERSION, T_SVNVER, z_svnver(), getpid(), z_username(userbuf, sizeof(userbuf)));
-    {
+    /*{
         void *codebase;
         char *libzia = z_libzia_file_name(&codebase);
         dbg("libzia: '%s' codebase 0x%p\n", libzia, codebase);
-    }
+    }*/
 
                 
     if (opt_i){
@@ -664,9 +681,6 @@ static void init(void)
 	masterdb = init_masterdb();
     init_sconns();
     init_rotars();
-#ifdef Z_HAVE_LIBFTDI
-	if (rotars->len > 0) hdkeyb = init_hdkeyb();
-#endif
 #ifdef Z_HAVE_SDL    
 	progress(VTEXT(T_INIT_MAP));		
     gcor = zcor_init(zsel, map_cor_callback, cor_tucnakcor, COR_ITEMS);
@@ -807,9 +821,6 @@ static void terminate_all_subsystems(void)
     free_wizz(wizz);
 	free_namedb(namedb);
 	free_masterdb(masterdb);
-#ifdef Z_HAVE_LIBFTDI
-    free_hdkeyb(hdkeyb);
-#endif
     free_rotars();
     free_spotdb(spotdb);
 	free_httpd(httpd);
