@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2020 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@ extern int first_contest_def;
 extern struct zselect *zsel;
 extern struct zfiledlg *zfiledlg;
 extern char *tucnak_dir;
+extern char *logs_dir;
 extern char *home_dir;
 
 void unhandle_terminal_signals(void);
@@ -39,4 +40,6 @@ void android_trace_keys(char *s);
 #endif
 
 void redraw(void);
+void set_logs_dir(void);
+
 #endif
