@@ -43,57 +43,59 @@
 
 
 /* only EV_KBD */
-int sw_map_kbd_func(struct subwin *sw, struct event *ev, int fw){
-    int lmx,lmy,step;
+int sw_map_kbd_func(struct subwin* sw, struct event* ev, int fw) {
+    int lmx, lmy, step;
     double stepd;
 
     if (!sdl) return 0;
-    step = (SDL_GetModState() & KMOD_SHIFT)!=0 ? 1 : 10;
+    step = (SDL_GetModState() & KMOD_SHIFT) != 0 ? 1 : 10;
     /*dbg("\nsw_map_kbd_func [%d,%d,%d,%d]\n",ev->ev,ev->x,ev->y,ev->b);*/
-    switch(kbd_action(KM_MAIN,ev)){
-        case ACT_ESC:
-            return 0;
-            break;
-        case ACT_LEFT:
-            sw->ox+=10;
-            move_map(sw, aband, +step, 0);
-            return 1;
-        case ACT_RIGHT:
-            sw->ox-=10;
-            move_map(sw, aband, -step, 0);
-            return 1;
-        case ACT_UP:
-            sw->oy+=10;
-            move_map(sw, aband, 0, +step);
-            return 1;
-        case ACT_DOWN:
-            sw->oy-=10;
-            move_map(sw, aband, 0, -step);
-            return 1;
+    switch (kbd_action(KM_MAIN, ev)) {
+    case ACT_ESC:
+        return 0;
+        break;
+    case ACT_LEFT:
+        sw->ox += 10;
+        move_map(sw, aband, +step, 0);
+        return 1;
+    case ACT_RIGHT:
+        sw->ox -= 10;
+        move_map(sw, aband, -step, 0);
+        return 1;
+    case ACT_UP:
+        sw->oy += 10;
+        move_map(sw, aband, 0, +step);
+        return 1;
+    case ACT_DOWN:
+        sw->oy -= 10;
+        move_map(sw, aband, 0, -step);
+        return 1;
 
     }
-   /* dbg("sw_map_kbd_func: %c %d\n", ev->x, ev->y);*/
-
-    stepd = (SDL_GetModState() & KMOD_SHIFT)!=0 ? 1.05 : 1.3;
-    switch(ev->x){
+    /* dbg("sw_map_kbd_func: %c %d\n", ev->x, ev->y);*/
+    int mod = SDL_GetModState();
+    if ((mod & (KMOD_CTRL | KMOD_ALT | KMOD_SHIFT)) == 0)
+    {
+        stepd = (mod & KMOD_SHIFT) != 0 ? 1.05 : 1.3;
+        switch (ev->x) {
         case '+':
         case '=':
-            lmx = sw->x * FONT_W + sw->screen->w/2;
-            lmy = sw->y * FONT_H + sw->screen->h/2;
-            zoom(sw, stepd, lmx, lmy);   
+            lmx = sw->x * FONT_W + sw->screen->w / 2;
+            lmy = sw->y * FONT_H + sw->screen->h / 2;
+            zoom(sw, stepd, lmx, lmy);
             break;
         case '-':
-            lmx = sw->x * FONT_W + sw->screen->w/2;
-            lmy = sw->y * FONT_H + sw->screen->h/2;
-            zoom(sw, 1/stepd, lmx, lmy);
+            lmx = sw->x * FONT_W + sw->screen->w / 2;
+            lmy = sw->y * FONT_H + sw->screen->h / 2;
+            zoom(sw, 1 / stepd, lmx, lmy);
             break;
-/*        case '1':
-            sw->ox+=20;
-            sw->oy+=20;
-            move_map(sw, +20, +20);
-            break;*/
+            /*        case '1':
+                        sw->ox+=20;
+                        sw->oy+=20;
+                        move_map(sw, +20, +20);
+                        break;*/
         case 'r':
-            sw->gdirty=1;
+            sw->gdirty = 1;
             qrv_recalc_wkd(qrv);
             qrv_recalc_qrbqtf(qrv);
             qrv_recalc_gst(qrv);
@@ -104,21 +106,22 @@ int sw_map_kbd_func(struct subwin *sw, struct event *ev, int fw){
             map_for_photo(sw, aband, 0);
             break;
         case 'c':
-            sw->ox=sw->map.w/2; 
-            sw->oy=sw->map.h/2; 
-            sw->gdirty=1;
-            redraw_later();
-			break;
-		case 'l':
-			sw->showlines = !sw->showlines;
-            sw->gdirty=1;
+            sw->ox = sw->map.w / 2;
+            sw->oy = sw->map.h / 2;
+            sw->gdirty = 1;
             redraw_later();
             break;
-		case 'w':
-			sw->showwwls = !sw->showwwls;
-            sw->gdirty=1;
+        case 'l':
+            sw->showlines = !sw->showlines;
+            sw->gdirty = 1;
             redraw_later();
             break;
+        case 'w':
+            sw->showwwls = !sw->showwwls;
+            sw->gdirty = 1;
+            redraw_later();
+            break;
+        }
     }
     return 0;
 }
@@ -435,6 +438,9 @@ void sw_map_redraw_icons(struct subwin *sw, SDL_Rect *area, int flags){
 
     memcpy(&r, area, sizeof(r));
 	plot_rain_titles(sdl->screen, &r, flags);
+
+    if (gacs && gacs->plot_info) gacs->plot_info(sw, area, gacs);
+
 //    if ((flags & HTML_FOR_PHOTO) == 0) plot_rotars(sw, sw->screen, area, &rotarea);
 }
 
@@ -656,7 +662,6 @@ void sw_map_redraw(struct subwin *sw, struct band *band, int flags){
 
     acs_redraw(sw, gacs);
 
-    if (!gacs) plot_info_qso(sw, sw->screen, sw->minqso);
 //    plot_info_qrv(sw, sw->screen, band, qrv_get(qrv, sw->minqrvcall));
     plot_qrb_qth(sw, sw->screen, sdl->mouse_x, sdl->mouse_y);
 //	ST_STOP; 
@@ -714,18 +719,6 @@ void pxkm2o(struct subwin *sw, int px, int py, int kx, int ky, int *ox, int *oy)
 
 
 
-static int dashcnt;
-static void dashfce(SDL_Surface *surface, int x, int y, int d) {
-    if (dashcnt++%6<3) return;
-    z_putpixel(surface, x, y, d);
-}
-
-static int dotcnt;
-static void dotfce(SDL_Surface *surface, int x, int y, int d) {
-	if (dotcnt++ % 6 != 3) return;
-	z_putpixel(surface, x, y, d);
-}
-
 
 void plot_cor(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, int flags){
     gpointer key;
@@ -1096,9 +1089,8 @@ void plot_rotars(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, SDL_Re
 		int kx = (ZLOC_R_EARTH * M_PI - 1) * cos(rad);
 		int ky = (ZLOC_R_EARTH * M_PI - 1) * sin(rad);
 		km2px(sw, kx, ky, &vxb, &vyb);
-		dotcnt = 0;
 		z_do_line(surface, vx, vy,
-			vxb, vyb, rot->color, dotfce);
+			vxb, vyb, rot->color, z_dotfce);
 
 
         if (rot->beamwidth<=0) continue;
@@ -1106,18 +1098,16 @@ void plot_rotars(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, SDL_Re
         rad = M_PI * (double)(rot->qtf - 90 + rot->beamwidth / 2) / 180.0;
         vx1 = (int)(sw->ox + 0.9 * r * cos(rad)); 
         vy1 = (int)(sw->oy + 0.9 * r * sin(rad));
-        dashcnt=0;
         z_do_line(surface, sw->ox, sw->oy,  
-                vx1, vy1, rot->color, dashfce);
+                vx1, vy1, rot->color, z_dashfce);
 
         rad = M_PI * (double)(rot->qtf - 90 - rot->beamwidth / 2) / 180.0;
         vx2 = (int)(sw->ox + 0.9 * r * cos(rad)); 
         vy2 = (int)(sw->oy + 0.9 * r * sin(rad));
-        dashcnt=0;
         z_do_line(surface, sw->ox, sw->oy,  
-                vx2, vy2, rot->color, dashfce);
+                vx2, vy2, rot->color, z_dashfce);
 
-        z_do_line(surface, vx1, vy1, vx2, vy2, rot->color, dashfce);
+        z_do_line(surface, vx1, vy1, vx2, vy2, rot->color, z_dashfce);
     }
     MUTEX_UNLOCK(rotars);
 }
@@ -1186,9 +1176,10 @@ int maps_reload(){
         sw->minqso=NULL;
 //        zg_free0(sw->minqrvcall);
         map_update_qth(sw);
+        map_recalc_gst(sw, aband); // added for band change
 
     }
-    
+
 	// next in map_cor_callback
     
     return 0;
@@ -1384,7 +1375,7 @@ void plot_info_qso(struct subwin *sw, SDL_Surface *surface, struct qso *qso){
     rect.h=sw->info.y+(11*FONT_H)+12;
     
     SDL_SetClipRect(surface, &rect);
-    SDL_FillRect(surface, &rect, z_makecol(0,0,35)) ;
+    SDL_FillRect(surface, &rect, z_makecol(0,0,135)) ;
     if (!qso) return;
 
     x=sw->info.x+4;
