@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2022  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -34,7 +34,7 @@ struct masterdb *init_masterdb(void){
 static gboolean free_masters_item(gpointer key, gpointer value, gpointer user_data){
     
     g_free(key);
-    return 0;    
+    return TRUE;    
 }
 
 void free_masterdb(struct masterdb *masterdb){
