@@ -21,10 +21,12 @@
 #include "map.h"
 #include "menu.h"
 #include "net.h"
+#include "oct8tor.h"
 #include "qrvdb.h"
 #include "qsodb.h"
 #include "rain.h"
 #include "rc.h"
+#include "rotar.h"
 #include "stats.h"
 #include "terminal.h"
 #include "tsdl.h"
@@ -119,6 +121,9 @@ void refresh_band_confb(void *xxx)
         }
 
     }
+#ifdef AUTOSAVE
+    menu_save_rc(NULL);
+#endif
 }
 
 void refresh_band(void *xxx)
@@ -490,6 +495,10 @@ void refresh_responsible_op(void *xxx)
     STORE_STR(cfg,rcoun);
     STORE_STR(cfg,rphon);
     STORE_STR(cfg,rhbbs);
+
+#ifdef AUTOSAVE
+    menu_save_rc(NULL);
+#endif
 }
 
 char *responsible_op_msg[] = {
@@ -1201,8 +1210,11 @@ void init_ctest2(int from_dlg, int updloc, struct zstring *zs2, struct wizz_item
         struct band *b;
         b=find_band_by_pband(cfg->startband);
         activate_band(b); /* b==NULL is handled by function */
-    }
-    
+	}
+#ifdef OCT8TOR
+	struct config_band *cb = get_config_band_by_bandchar(aband->bandchar);
+	oct8tor_send_band(goct8tor, cb->adifband);
+#endif
 }
 
 void contest_options1_fn(struct dialog_data *dlgd)
@@ -1773,12 +1785,18 @@ void refresh_contest_def(void *xxx)
 
 		}else{
 			first_contest_def=0;
+#ifndef AUTOSAVE
 			menu_save_rc(NULL);
+#endif
 		}
 	}
     net_send_operator();
     net_send_read_write_bands();
 	net_send_talk();
+#ifdef AUTOSAVE
+    menu_save_rc(NULL);
+#endif
+
 }
 
 
