@@ -1095,7 +1095,7 @@ void do_ssbd(void){
 
 #ifdef HAVE_PORTAUDIO
     if (cfg->ssbd_pa_play_s != NULL && strlen(cfg->ssbd_pa_play_s) >= 0) {
-        cfg->ssbd_pa_play = pa_find_device(cfg->ssbd_pa_play_s, 1, 0);
+        cfg->ssbd_pa_play = pa_find_device(cfg->ssbd_pa_play_s, cfg->ssbd_pa_play_hi, 1, 0);
     }
 	if (cfg->ssbd_pa_play < 0) cfg->ssbd_pa_play = Pa_GetDefaultOutputDevice();
     di = Pa_GetDeviceInfo(cfg->ssbd_pa_play);
@@ -1108,7 +1108,7 @@ void do_ssbd(void){
 	}
     
     if (cfg->ssbd_pa_rec_s != NULL && strlen(cfg->ssbd_pa_rec_s) >= 0) {
-        cfg->ssbd_pa_rec = pa_find_device(cfg->ssbd_pa_rec_s, 1, 0);
+        cfg->ssbd_pa_rec = pa_find_device(cfg->ssbd_pa_rec_s, cfg->ssbd_pa_rec_hi, 0, 1);
     }
     if (cfg->ssbd_pa_rec < 0) cfg->ssbd_pa_rec = Pa_GetDefaultInputDevice();
     di = Pa_GetDeviceInfo(cfg->ssbd_pa_rec);
