@@ -222,7 +222,7 @@ void misc_opts(void *arg)
 		d->items[++i].type = D_FIELD;
 		d->items[i].fn = check_number;
 		d->items[i].gid = 13;
-		d->items[i].gnum = 32;
+		d->items[i].gnum = 40;
 		d->items[i].maxl = 5;
 		d->items[i].dlen = EQSO_LEN;
 		d->items[i].data = fontheight_str;
@@ -1174,11 +1174,11 @@ void refresh_rotar_opts(void *xxx){
     STORE_SINT(crot, rot_saddr);
     STORE_STR (crot, rot_rem_rotstr); 
 
-MUTEX_LOCK(rotars);
+//MUTEX_LOCK(rotars);
     free_rotars();
     init_rotars();
 	progress(NULL);
-MUTEX_UNLOCK(rotars);
+//MUTEX_UNLOCK(rotars);
 
 #ifdef AUTOSAVE
     menu_save_rc(NULL);
