@@ -467,6 +467,15 @@ void menu_ac_opts(void *arg){
     d->items[i].data = (char *)&ac_enable;
     d->items[i].msg = CTEXT(T_ENABLE_AC);
     d->items[i].wrap = 1;
+    /////////////////////////////////////////////////////////////
+    d->items[++i].type = D_CHECKBOX;
+    d->items[i].gid = 1;
+    d->items[i].gnum = AC_AIRSCATTER_DK;
+    d->items[i].dlen = sizeof(int);
+    d->items[i].data = (char*)&ac_provider;
+    d->items[i].msg = TRANSLATE("Airscatter.dk");
+    d->items[i].wrap = 1;
+
     /////////////////////////////////////////////////////////////
     d->items[++i].type = D_CHECKBOX;
     d->items[i].gid = 1;
