@@ -60,9 +60,8 @@
 #define HAVE_PORTAUDIO
 #define HAVE_LIBFFTW3
 #define HAVE_HAMLIB
-//#define HAVE_LIBFTDI
-//#define HAVE_FTDI_NEW
 #define HAVE_LIBRTLSDR
+#define HAVE_HIDAPI
 #define HAVE_SHLOBJ_H
 #define HAVE_RIG_SEND_VOICE_MEM
 #define HAVE_RIG_SEND_MORSE
