@@ -1706,8 +1706,10 @@ int worked_on_all_rw(char *call){
 
 int worked_on_aband(char *call){
     if (!aband) return 0;
-			
-    if (get_qso_by_callsign(aband, call)){
+		
+    struct qso* q = get_qso_by_callsign(aband, call);
+    if (q != NULL){
+        if (q->phase != ctest->phase) return 0;
         return 1;   
     }
     else{
