@@ -42,6 +42,13 @@
     else base->item = def; \
 }
 
+#define STORE_HASH_DOUBLE_DEF(base, item, def) {\
+    gchar *c; \
+    c = (char*)g_hash_table_lookup(hash, #item); \
+    if (c) base->item = atof(c); \
+	    else base->item = def; \
+}
+
 #define STORE_HASH_ENUM_DEF(base, item, type, def) {\
     gchar *c; \
     c = (char*)g_hash_table_lookup(hash, #item); \
