@@ -67,7 +67,7 @@ struct rain *init_rain(){
 	rain->scps = g_ptr_array_new_with_free_func((GDestroyNotify)free_rain_scp);
 	rain->scplocs = g_string_sized_new(256);
 
-	if (cfg->rain_meteox){
+	if (0 && cfg->rain_meteox){ // DISABLED
 		struct rain_provider *provider = g_new0(struct rain_provider, 1);
 		provider->rain = rain;
 		provider->name = "meteox";
@@ -105,7 +105,7 @@ struct rain *init_rain(){
 		rain->meteox = provider;
 	}
 
-	if (cfg->rain_wetteronline){
+	if (0 && cfg->rain_wetteronline){ // DISABLED
 		struct rain_provider *provider = g_new0(struct rain_provider, 1);
 		provider->rain = rain;
 		provider->name = "wetteronline";
