@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011-2020 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2023 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -74,7 +74,7 @@ struct config {   /* depending on callsign */
     gint cwda_speed, cwda_weight, cwda_minwpm, cwda_maxwpm;
     gint cwda_leadin, cwda_tail, cwda_spk;
     gint cwda_vid, cwda_pid, cwda_autgive;
-    gint wk_wk2, wk_usepot, wk_usebut, wk_keymode, wk_swap;
+    gint wk_wk2, wk_usepot, wk_usebut, wk_keymode, wk_swap, wk_echoback;
     
     gint ssbd_type;
     gint ssbd_record, ssbd_maxmin, ssbd_diskfree;
@@ -87,6 +87,8 @@ struct config {   /* depending on callsign */
 	gint ssbd_buffer_time;
     gchar *ssbd_alsa_mixer, *ssbd_alsa_src;
     int ssbd_pa_play, ssbd_pa_rec;
+    int ssbd_pa_play_hi, ssbd_pa_rec_hi;
+    gchar *ssbd_pa_play_s, *ssbd_pa_rec_s;
 
     gchar *ssbd_dsp;
     gint ssbd_maxfrag;
@@ -103,6 +105,10 @@ struct config {   /* depending on callsign */
     
     GPtrArray *crotars;  /* of struct config_rotar */
     struct config_rotar *crotar;
+#ifdef OCT8TOR
+	int oct_enable, oct_comm, oct_local_udp_port, oct_remote_tcp_port, oct_debug, oct_alloc;
+	char *oct_tcp_host, *oct_serial_port;
+#endif	
     int loglines,skedcount;
     gchar *startband;
     GPtrArray *takeoff; /* of struct takeoff */
@@ -131,14 +137,23 @@ struct config {   /* depending on callsign */
     int httpd_show_links;
 
     int ac_enable;       // aircraft is enabled
-    char *ac_url;        // URL for fligtradar data
+    int ac_provider;
+
+    char* ac_osn_username, *ac_osn_password;
+    int ac_osn_minutes;
+    int ac_adsbone_minutes;
+
+    char *ac_filename;   // feed file name
+
+    char* ac_centerwwl;
     double ac_kfactor;   // troposphere k_factor
     double ac_arwidth;   // area width in km
     double ac_minelev;   // minimal elevation angle
     double ac_maxelev;   // maximal elevation angle
     int ac_mindur;       // minimal reflections duration in seconds
     double ac_maxdelta;  // max difference of incidence and reflection angles
-	int ac_minalt;       // minimal AC altitude to show on map in meters
+	int ac_minalt;       // minimal AC altitude to show on map in meters. Read from thread
+	int ac_imperial;     // display imperial units
 
 	int sdr_enable, sdr_cw, sdr_lsb, sdr_speed, sdr_af_speed, sdr_block, sdr_iqcomp;
 	double sdr_zero, sdr_cw_low, sdr_cw_high, sdr_ssb_low, sdr_ssb_high;
@@ -172,6 +187,9 @@ int term_spec_init(void);
 char *parse_options(int argc, char **argv);
 gdouble get_rig_lo(struct band *band, int rignr);
 void set_rig_lo(struct band *band, int rignr, gdouble lo);
+struct zstring *def_format(struct config *cfg);
+void def_parse(struct zstring *zs, struct config *cfg);
+
 
 
 
