@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,27 +28,27 @@ int write_report(struct band *b, struct config_band *confb, FILE *f){
     month = (date/100)%100;
     year = (date/10000)%10000;
     
-    g_string_sprintfa(gs, "s OK1KPA\n");
-    g_string_sprintfa(gs, "Hlaseni ze zavodu %s %d/%d %s\n", ctest->tname, month, year, z_str_uc(safe_strncpy0(s, ctest->pcall, 21)));
-    g_string_sprintfa(gs, "\n\n");
-    g_string_sprintfa(gs, "Hlaseni ze zavodu %s %d/%d \n", ctest->tname, month, year);
-    g_string_sprintfa(gs, "\n");
-    g_string_sprintfa(gs, "Hlaseni ze zavodu:      %s  dne %02d.%02d.%2d \n", ctest->tname, day, month, year);
-    g_string_sprintfa(gs, "Kategorie:              %s (%s %s)\n", b->psect ? confb->ok_section_single : confb->ok_section_multi,
+    g_string_append_printf(gs, "s OK1KPA\n");
+    g_string_append_printf(gs, "Hlaseni ze zavodu %s %d/%d %s\n", ctest->tname, month, year, z_str_uc(safe_strncpy0(s, ctest->pcall, 21)));
+    g_string_append_printf(gs, "\n\n");
+    g_string_append_printf(gs, "Hlaseni ze zavodu %s %d/%d \n", ctest->tname, month, year);
+    g_string_append_printf(gs, "\n");
+    g_string_append_printf(gs, "Hlaseni ze zavodu:      %s  dne %02d.%02d.%2d \n", ctest->tname, day, month, year);
+    g_string_append_printf(gs, "Kategorie:              %s (%s %s)\n", b->psect ? confb->ok_section_single : confb->ok_section_multi,
                 b->pband, b->psect ? "Single" : "Multi");
-    g_string_sprintfa(gs, "Znacka v zavode:        %s \n", z_str_uc(safe_strncpy0(s, ctest->pcall, 21)));
-    g_string_sprintfa(gs, "Lokator:                %s \n", z_str_uc(safe_strncpy0(s, ctest->pwwlo, 7)));
-    g_string_sprintfa(gs, "Pocet platnych spojeni: %d \n", b->stats->nqsos);
-    g_string_sprintfa(gs, "Pocet bodu za spojeni:  %d \n", b->stats->nqsop);
-    g_string_sprintfa(gs, "Pocet nasobicu:         %d \n", g_hash_table_size(b->stats->wwls));
-    g_string_sprintfa(gs, "Vysledek:               %d \n", b->stats->ntotal);
-    g_string_sprintfa(gs, "\n");
-    g_string_sprintfa(gs, "Prohlasuji, ze jsem dodrzel(a) podminky zavodu, \n");
-    g_string_sprintfa(gs, "uvedeny vysledek odpovida skutecnosti. \n");
-    g_string_sprintfa(gs, "%30s\n", ctest->pcall);
-    g_string_sprintfa(gs, "\n");
-    g_string_sprintfa(gs, "/ack\n");
-    g_string_sprintfa(gs, "/ex\n");
+    g_string_append_printf(gs, "Znacka v zavode:        %s \n", z_str_uc(safe_strncpy0(s, ctest->pcall, 21)));
+    g_string_append_printf(gs, "Lokator:                %s \n", z_str_uc(safe_strncpy0(s, ctest->pwwlo, 7)));
+    g_string_append_printf(gs, "Pocet platnych spojeni: %d \n", b->stats->nqsos);
+    g_string_append_printf(gs, "Pocet bodu za spojeni:  %d \n", b->stats->nqsop);
+    g_string_append_printf(gs, "Pocet nasobicu:         %d \n", g_hash_table_size(b->stats->wwls));
+    g_string_append_printf(gs, "Vysledek:               %d \n", b->stats->ntotal);
+    g_string_append_printf(gs, "\n");
+    g_string_append_printf(gs, "Prohlasuji, ze jsem dodrzel(a) podminky zavodu, \n");
+    g_string_append_printf(gs, "uvedeny vysledek odpovida skutecnosti. \n");
+    g_string_append_printf(gs, "%30s\n", ctest->pcall);
+    g_string_append_printf(gs, "\n");
+    g_string_append_printf(gs, "/ack\n");
+    g_string_append_printf(gs, "/ex\n");
     
     
     if (fprintf(f, "%s", gs->str) != gs->len) ret=1;
