@@ -194,7 +194,7 @@ struct sdr *init_sdr(void){
 	int i, j = 0, r, f;
     struct sdr *sdr;
    
-    dbg("init_sdr  enable=%d\n", cfg->sdr_enable);
+    //dbg("init_sdr  enable=%d\n", cfg->sdr_enable);
 	if (!cfg->sdr_enable) return NULL;
     //if (!sdl) return NULL;
 
