@@ -19,6 +19,7 @@
 
 //#include <time.h> // time() should come from ztime.h from libzia
 #include <libzia.h>
+#include <zjson0.h>
 
 #include "main.h"
 
@@ -76,7 +77,7 @@ int sota_api_get_token(struct sota_api_data *sad)
     gs = g_string_sized_new(250);
 
     //zg_string_eprintfa("", gs, "http://192.168.11.181/");
-    zg_string_eprintfa("", gs, "http://www.emuf.cz/sotalog/tokentest/");
+    zg_string_eprintfa("", gs, "http://sota.emuf.cz:8044/tokentest/");
     //zg_string_eprintfa("", gs, "https://sso.sota.org.uk/auth/realms/SOTA/protocol/openid-connect/token");
     zg_string_eprintfa("u", gs, "?client_id=tucnak"); 
     zg_string_eprintfa("u", gs, "&client_secret=" SOTA_CLIENT_SECRET); 
@@ -137,8 +138,8 @@ void sota_api_parse_token(struct zhttp *zh)
     - session_state
     - scope
 */
-    sad->error = zjson_get_str(zh->datastr, -1, "error");
-    sad->error_description = zjson_get_str(zh->datastr, -1, "error_description");
+    sad->error = zjson0_get_str(zh->datastr, -1, "error");
+    sad->error_description = zjson0_get_str(zh->datastr, -1, "error_description");
 
     if (sad->error != NULL)
     {
@@ -149,8 +150,8 @@ void sota_api_parse_token(struct zhttp *zh)
         return;
     }
 
-    sad->access_token = zjson_get_str(zh->datastr, -1, "access_token");
-    sad->id_token = zjson_get_str(zh->datastr, -1, "id_token");
+    sad->access_token = zjson0_get_str(zh->datastr, -1, "access_token");
+    sad->id_token = zjson0_get_str(zh->datastr, -1, "id_token");
     if (sad->access_token && sad->id_token)
     {
         sad->state = SOTA_SSO_VALID;
@@ -214,17 +215,17 @@ int sota_api_send_spot(struct sota_api_data *sad)
     */
 
     //zjson_object_start(json_data, "");
-    zjson_item_int(json_data, "id", 0);
-    zjson_item_string(json_data, "associationCode", sad->ssd->associationCode);
-    zjson_item_string(json_data, "summitCode", sad->ssd->summitCode);
-    zjson_item_string(json_data, "Callsign", sad->ssd->callsign);
-    zjson_item_string(json_data, "activatorCallsign", sad->ssd->activatorCallsign);
-    zjson_item_string(json_data, "frequency", sad->ssd->frequency);
-    zjson_item_string(json_data, "mode", sad->ssd->mode);
-    zjson_item_string(json_data, "comments", sad->ssd->comment);
-    zjson_item_string(json_data, "highlightColor", "default");
-    zjson_object_end(json_data);
-    zjson_strip(json_data);
+    zjson0_item_int(json_data, "id", 0);
+    zjson0_item_string(json_data, "associationCode", sad->ssd->associationCode);
+    zjson0_item_string(json_data, "summitCode", sad->ssd->summitCode);
+    zjson0_item_string(json_data, "Callsign", sad->ssd->callsign);
+    zjson0_item_string(json_data, "activatorCallsign", sad->ssd->activatorCallsign);
+    zjson0_item_string(json_data, "frequency", sad->ssd->frequency);
+    zjson0_item_string(json_data, "mode", sad->ssd->mode);
+    zjson0_item_string(json_data, "comments", sad->ssd->comment);
+    zjson0_item_string(json_data, "highlightColor", "default");
+    zjson0_object_end(json_data);
+    zjson0_strip(json_data);
 
     //zhttp_post_json(sad->http_spot, zsel, "http://192.168.11.181", 
     zhttp_post_json(sad->http_spot, zsel, "https://api2.sota.org.uk/api/spots/",
@@ -276,7 +277,7 @@ int sota_api_send_spot_insecure(struct sota_api_data *sad)
     tokenize(gs_token);
     zhttp_post_add(sad->http_spot, "token", gs_token->str);
 
-    zhttp_post(sad->http_spot, zsel, "http://www.emuf.cz/sotalog/spots/",
+    zhttp_post(sad->http_spot, zsel, "http://sota.emuf.cz:8044/spots/",
                     sota_api_spot_sent, sad);
 
     g_string_free(gs_token, TRUE);
@@ -295,8 +296,8 @@ static void sota_api_spot_sent(struct zhttp *http_spot)
         return;
     }
 
-    sad->error = zjson_get_str(http_spot->datastr, -1, "error");
-    sad->error_description = zjson_get_str(http_spot->datastr, -1, "error_description");
+    sad->error = zjson0_get_str(http_spot->datastr, -1, "error");
+    sad->error_description = zjson0_get_str(http_spot->datastr, -1, "error_description");
 
     if (sad->error != NULL)
     {
@@ -307,10 +308,10 @@ static void sota_api_spot_sent(struct zhttp *http_spot)
         return;
     }
 
-    sad->status = zjson_get_str(http_spot->datastr, -1, "status");
+    sad->status = zjson0_get_str(http_spot->datastr, -1, "status");
 
-    sad->ssd->id = zjson_get_int(http_spot->datastr, -1, "id");
-    sad->ssd->userID = zjson_get_int(http_spot->datastr, -1, "userId");
+    sad->ssd->id = zjson0_get_int(http_spot->datastr, -1, "id");
+    sad->ssd->userID = zjson0_get_int(http_spot->datastr, -1, "userId");
 
     log_addf("SOTA %s (id=%i)", sad->status, sad->ssd->id);
     //log_addf("SOTA spot submitted (id=%i)", sad->ssd->id);
