@@ -63,7 +63,7 @@ void sota_upload(void){
     g_string_append_printf(gs2, "%-7s  %-4s\n", "Band", "QSOs"); 
     g_string_insert(gs, 0, gs2->str);
     g_string_free(gs2, TRUE);
-    g_string_append_printf(gs, TRANSLATE("\nUpload report to www.emuf.cz/sotalog?"));
+    g_string_append_printf(gs, TRANSLATE("\nUpload report to http://sota.emuf.cz:8044?"));
 
 
     c = g_strdup(gs->str);
@@ -93,7 +93,7 @@ void sota_do_upload(void *arg){
     zhttp_post_add(zhts, "date", ctest->cdate);
     // TODO: switch to HTTPS
     //zhttp_post(zhts, zsel, "http://192.168.11.181/work/sotalog/upload.php",sota_upload_done, NULL);
-    zhttp_post(zhts, zsel, "http://www.emuf.cz/sotalog/upload.php",sota_upload_done, NULL);
+    zhttp_post(zhts, zsel, "http://sota.emuf.cz:8044/upload.php",sota_upload_done, NULL);
 
     g_free(filename);    
     
@@ -107,7 +107,7 @@ static void sota_upload_done(struct zhttp *http){
     }
     else
     {
-        log_addf("SOTA Log uploaded to http://www.emuf.cz/sotalog");
+        log_addf("SOTA Log uploaded to http://sota.emuf.cz:8044");
     }
 
     zhttp_post_free(http);
