@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2022 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -71,7 +71,7 @@ struct ssbd {
 extern struct ssbd *gssbd;
 
 struct ssbd *init_ssbd(void);
-void free_ssbd(struct ssbd *ssbd);
+void free_ssbd(struct ssbd *ssbd, int terminate);
 void ssbd_abort(struct ssbd *ssbd, int abort_rec);
 int ssbd_recording(struct ssbd *ssbd);
 
