@@ -184,6 +184,17 @@ void clear_stats(struct stats *st){
 	st->oldphase = 1;
 }
 
+int find_str_in_arr(const char *str, const char *values[]) {
+    if (values == NULL)
+        return -1;
+
+    for (int i = 0; values[i] != NULL; i++)
+        if (strcasecmp(str, values[i]) == 0)
+            return i;
+
+    return -1;
+}
+
 int find_preferred_dxc(int type, char *dxc){
 	char *prefs9[]  = {"ES","LA","LY","OH","OH0","OJ0","OY","OZ","SM","TF","YL",NULL};
 	char *prefs10[] = {"G","GD","GI","GJ","GM","GU","GW",NULL};
@@ -191,7 +202,6 @@ int find_preferred_dxc(int type, char *dxc){
     char *prefs16[] = {"F","TK", "TM",NULL}; 
 	char **prefs;
 	int multi=1;
-	int i;  
 	
 	switch(type){
 		case 9: 
@@ -216,12 +226,46 @@ int find_preferred_dxc(int type, char *dxc){
 			return 1;	
 	}
 
-	for (i=0; prefs[i]!=NULL; i++){
-		if (strcasecmp(dxc,prefs[i])==0) return multi;
-	}
+	if (find_str_in_arr(dxc, (const char**)prefs) != -1)
+		return multi;
 	return 1;
-	
 }
+
+int iac_bonus(struct band *band, struct qso *qso) {
+    const char *bonus_250[] = {"JN35", "JN44", "JN45", "JN53",
+                          "JN54", "JN55", "JN65", NULL};
+    const char *bonus_500[] = {"JN33", "JN34", "JN40", "JN41", "JN43",
+                          "JN46", "JN52", "JN56", "JN61", "JN62",
+                          "JN63", "JN64", "JN66", "JN72", NULL};
+    const char *bonus_1000[] = {
+        "JM48", "JM49", "JM56", "JM65", "JM66", "JM67", "JM68", "JM76", "JM77",
+        "JM78", "JM79", "JM87", "JM88", "JM89", "JM99", "JN36", "JN51", "JN57",
+        "JN60", "JN67", "JN70", "JN71", "JN80", "JN81", "JN90", NULL};
+    gchar s[20];
+
+    // no bonus after 1,3 GHz
+    if (band->qrg_min > 2000000)
+        return 0;
+
+    get_dxcc(dw, s, qso->callsign);
+    if (strcasecmp(s, "I") != 0)
+        return 0;
+
+    int bonus = 0;
+    get_wwl(s, qso->locator);
+
+    if(find_str_in_arr(s, bonus_250) != -1)
+        bonus = 250;
+    else if(find_str_in_arr(s, bonus_500) != -1)
+        bonus = 500;
+    else if(find_str_in_arr(s, bonus_1000) != -1)
+        bonus = 1000;
+
+    dbg("IAC: WWL: %s  Bonus: %4d Callsign: %s\n", s, bonus, qso->callsign);
+
+    return bonus;
+}
+
 /* set and dirty */
 #define SAD_INT(item,value) {if (q->item!=value) band->dirty_save=1;q->item=value;}
 
@@ -421,6 +465,8 @@ void update_stats(struct band *band, struct stats *st, struct qso *q){
 		case 22: /* Moon contest */
 			qsop = iaru_round(q->qrb) * ctest->qsomult * band->qsomultb; // same as IARU
 			break;
+        case 23: /* Italian Activity Contest - IAC */
+            qsop = iaru_round(q->qrb) * band->qsomultb;
 
     }
     if (q->dupe) qsop=0;
@@ -480,6 +526,15 @@ void update_stats(struct band *band, struct stats *st, struct qso *q){
 				anew |= NEW_WWL;
 			}
 		}
+
+        int bonus = 0;
+        if (ctest->qsop_method == 23 &&              // IAC
+            (anew & NEW_WWL) &&                      // New WWL
+            (bonus = iac_bonus(band,q)) > 0) {       // has bonus
+            qsop += bonus;
+            SAD_INT(qsop,qsop);
+            st->nqsop += bonus;
+        }
     }
     
 
