@@ -498,6 +498,7 @@ void free_subwin(struct subwin *sw){
 	g_free(sw->pattern);
 	g_free(sw->player_filename);
 	zbinbuf_free(sw->wrbuf);
+    if (sw->zser) zserial_free(sw->zser);
     g_free(sw);
 }
 
@@ -2385,7 +2386,7 @@ void sw_export_lines(struct subwin *sw, char *fname){
 int sw_shake_tmo = -1;
 void sw_shake(struct subwin *sw, int down){
 #if defined(Z_HAVE_SDL) && !defined(Z_MACOS)
-	SDL_Surface *old;
+	SDL_Surface *old = NULL;
 	SDL_Rect src, dst, fill;
     int len;
 	int h;
@@ -2469,6 +2470,7 @@ void sw_shake(struct subwin *sw, int down){
 	SDL_BlitSurface(old, NULL, sdl->screen, &dst);
 	SDL_UpdateRect(sdl->screen, dst.x, dst.y, dst.w, dst.h);
 x:;
+    if (old != NULL) SDL_FreeSurface(old);
 	sw->shaking = 0;
 #endif
 }
@@ -2504,7 +2506,8 @@ int sw_accel_dy(struct subwin *sw, struct event *ev){
 
 void sw_highlight(struct subwin *sw, const char *text, const char *needle, int color, int i, int whole){
     const gchar *cc;
-	char *fd, *d, after; 
+	char *fd, *d;
+	unsigned char after;
     int rx, fx, fl, ho; 
 	int needlelen = strlen(needle);
     
@@ -2517,7 +2520,7 @@ void sw_highlight(struct subwin *sw, const char *text, const char *needle, int c
     while ((d = z_strcasestr(cc, needle)) != NULL){ 
 		if (whole){
 			if (d > cc){
-				int before = d[-1];
+				unsigned char before = d[-1];
 				if (isalnum(before)) {
 					cc = d + strlen(needle); 
 					continue;
