@@ -128,7 +128,7 @@ struct subwin {
 	int dxc_from_net;
 	int timer_id;
 	GHashTable *kstusers;  // of qrv_item (foreign key, can be NULL)
-	GHashTable *kstoldusers;
+	GHashTable *tmpkstusers;
 	int shus;	// 0 = none, 1 = from timer with filter, 2 = from operator
 	int kst_y, kst_offset;
 	int allqsos;
