@@ -359,6 +359,7 @@ struct trig *init_trig(struct config_rig *crig){
 	trig->ssbcw_shift = crig->rig_ssbcw_shift;
 	trig->clr_rit = crig->rig_clr_rit;
 	trig->ptt_t2r = crig->rig_ptt_t2r;
+	trig->conf = g_strdup(crig->rig_conf);
 
     MUTEX_INIT(trig->jobs);
    
@@ -368,6 +369,8 @@ struct trig *init_trig(struct config_rig *crig){
 		rig_cleanup(tmprig);
 	}
 
+	trig_set_conf(trig);
+
 	if (rp == RIG_PORT_SERIAL && cfg->nolocks == 0){
         ret = zfhs_lock(trig->filename, 1);
         if (ret){
@@ -406,13 +409,14 @@ void free_trig(struct trig *trig){
         dbg("done\n");
         trig->thread=0;
     }
-    if (trig->rig){
+	if (trig->locked) zfhs_unlock(trig->filename);
+	if (trig->rig){
         rig_close(trig->rig);
         rig_cleanup(trig->rig);
-        zg_free0(trig->filename);
+		zg_free0(trig->filename);
+		zg_free0(trig->conf);
         trig->rig = NULL;
     }
-    if (trig->locked) zfhs_unlock(trig->filename);
     MUTEX_FREE(trig->jobs);
 	g_free(trig);
 }
@@ -684,6 +688,7 @@ gpointer trig_main(gpointer xxx){
 					TRTR(1, "rig_get_rit(#%d, %s)", trig->nr, rig_strvfo(vfo));
 				}
 				if (rigerr == RIG_OK){
+					if (tmprit < -10000 || tmprit > 10000) continue; // obviously mistake
 					rit = tmprit;
 					if (rit != oldrit){
 						oldrit = rit;
@@ -881,4 +886,39 @@ char *trig_short_errstr(enum rig_errcode_e error){
     }
 }
 
+void trig_set_conf(struct trig *trig)
+{
+	if (!trig || !trig->conf) return;
+
+	char *param = trig->conf;
+	while (param && *param != '\0'){
+		int ret;
+
+		char* value = strchr(param, '=');
+		if (!value) {
+			log_addf(TRANSLATE("No rig config value sepatator"), param);
+			return;
+		}
+
+		*value++ = '\0';
+		char *n = strchr(value, ',');
+
+		if (n) *n++ = '\0';
+
+		int token = rig_token_lookup(trig->rig, param);
+		if (token != 0){
+			ret = rig_set_conf(trig->rig, rig_token_lookup(trig->rig, param), value);
+
+			if (ret != RIG_OK){
+				log_addf(TRANSLATE("Can't set rig parameter %s"), param);
+				return;
+			}
+		}else{
+			log_addf(TRANSLATE("Invalid rig config parameter %s"), param);
+		}
+		param = n;
+	}
+}
+
+
 #endif
