@@ -13,6 +13,7 @@
 #include "bfu.h"
 #include "cwwindow.h"
 #include "fifo.h"
+#include "fonts.h"
 #include "icons.h"
 #include "kbd.h"
 #include "main.h"
@@ -56,6 +57,10 @@ int getaltstate(){
 }
 #endif
 
+#ifdef Z_HAVE_SDL_TTF
+#include "fonts.inc"
+#endif
+
 char *dumpmods(SDL_Keysym *sym){
 	static GString *gs = NULL;
 	if (gs == NULL) gs = g_string_sized_new(256);
@@ -300,6 +305,9 @@ void free_sdl(){
     if (sdl->xfer) SDL_FreeSurface(sdl->home);
     if (sdl->xfer) SDL_FreeSurface(sdl->zoomin);
     if (sdl->xfer) SDL_FreeSurface(sdl->zoomout);
+#ifdef Z_HAVE_SDL_TTF
+    if (sdl->ttf_rwops != NULL) SDL_RWclose(sdl->ttf_rwops);
+#endif
     MUTEX_FREE(sdl->eventpipestate);
     zg_free0(sdl->title);
 
@@ -469,7 +477,7 @@ int sdl_setvideomode(int w, int h, int init_x){
 		dbg("SDL_SetVideoMode(%d,%d) failed\n", w, h);
 		return 1;    
 	}
-	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse);
+	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse, NULL);
 
 #endif
 #ifdef Z_HAVE_SDL2
@@ -506,10 +514,6 @@ int sdl_setvideomode(int w, int h, int init_x){
 	//sdl->screen = SDL_CreateRGBSurface(SDL_SWSURFACE, w, h, pxformat->BitsPerPixel, pxformat->Rmask, pxformat->Gmask, pxformat->Bmask, pxformat->Amask);
 	sdl->screen = SDL_GetWindowSurface(win);
 
-	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse);
-	zsdl->window = win;
-	zsdl->format = format;
-	zsdl->pxformat = pxformat;
 	
 	/*SDL_SetWindowResizable(zsdl->window, SDL_TRUE);
 	if (cfg->fullscreen){
@@ -518,6 +522,20 @@ int sdl_setvideomode(int w, int h, int init_x){
 	//SDL_StartTextInput();
 #endif
 
+#ifdef Z_HAVE_SDL_TTF
+    sdl->ttf_rwops = SDL_RWFromConstMem(font_JetBrainsMono_Regular, sizeof(font_JetBrainsMono_Regular));
+	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse, sdl->ttf_rwops);
+#else
+	zsdl = zsdl_init(sdl->screen, cfg->fontheight, cfg->inverse, NULL);
+#endif
+
+#ifdef Z_HAVE_SDL2
+    zsdl->window = win;
+    zsdl->format = format;
+    zsdl->pxformat = pxformat;
+#endif
+
+
     //if (SDL_MUSTLOCK(sdl->screen)) zinternal("surface must be locked");
     sdl->termarea.x = 0;
     sdl->termarea.y = 0;
@@ -1713,16 +1731,34 @@ void tsdl_change_font(char how){
 	if (!sdl) return;
 
 	if (how == '+'){
-		if (cfg->fontheight == 32) return;
-		if (cfg->fontheight < 16) cfg->fontheight = 16;
-		else if (cfg->fontheight < 24) cfg->fontheight = 24;
-		else cfg->fontheight = 32;
+#ifdef Z_HAVE_SDL_TTF
+        if (zsdl->ttf != NULL) {
+            if (cfg->fontheight >= 40) return;
+            cfg->fontheight += 2;
+        }
+        else
+#endif
+        {
+            if (cfg->fontheight == 32) return;
+            if (cfg->fontheight < 16) cfg->fontheight = 16;
+            else if (cfg->fontheight < 24) cfg->fontheight = 24;
+            else cfg->fontheight = 32;
+        }
 	}
 	if (how == '-'){
-		if (cfg->fontheight == 13) return;
-		if (cfg->fontheight > 24) cfg->fontheight = 24;
-		else if (cfg->fontheight > 16) cfg->fontheight = 16;
-		else cfg->fontheight = 13;
+#ifdef Z_HAVE_SDL_TTF
+        if (zsdl->ttf != NULL) {
+            if (cfg->fontheight <= 12) return;
+            cfg->fontheight -= 2;
+        }
+        else
+#endif
+        {
+            if (cfg->fontheight == 13) return;
+            if (cfg->fontheight > 24) cfg->fontheight = 24;
+            else if (cfg->fontheight > 16) cfg->fontheight = 16;
+            else cfg->fontheight = 13;
+        }
 	}
 	sdl_setvideomode(sdl->screen->w, sdl->screen->h, 0);
 	resize_terminal(NULL);
