@@ -64,6 +64,11 @@ struct tsdl{
 	int old_mouse_x, old_mouse_y;
     int altsym;
 	int ignore_progress;
+#ifdef Z_HAVE_SDL_TTF
+    SDL_RWops* ttf_rwops;
+#endif
+    //SDL_RWclose(fontRW);
+
 };
 
 
