@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2012-2014 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2012-2020 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -8,6 +8,8 @@
 
 */
 
+#include "header.h"
+
 #include "zosk.h"
 
 #ifdef Z_HAVE_SDL
@@ -21,14 +23,15 @@
 #define sdlkey(key) case key: strcat(s, #key); break
 
 #define ZOSK_KEYY (zosk->font_h + 10 + 10)
-#define ZOSK_LEFT ((SDLKey)-10)
-#define ZOSK_RIGHT ((SDLKey)-11)
+#define ZOSK_LEFT ((SDL_Keycode)-10)
+#define ZOSK_RIGHT ((SDL_Keycode)-11)
 #define ZOSK_TP_CENTER 0
 #define ZOSK_TP_LEFT 1
 #define ZOSK_TP_RIGHT 2
 
-char *zosk_sym2text(struct zosk *zosk, struct zosk_key *key, SDLKey sym){
+char *zosk_sym2text(struct zosk *zosk, struct zosk_key *key, SDL_Keycode sym){
 	static char txt[5];
+	
     switch ((int)sym){
 	    case SDLK_LSHIFT:    key->isshift = 1; zosk->shift = key; return "SH";
         case SDLK_LCTRL:     key->isshift = 1; zosk->ctrl = key;  return "Ctrl";
@@ -57,7 +60,7 @@ char *zosk_sym2text(struct zosk *zosk, struct zosk_key *key, SDLKey sym){
 
 }
 
-struct zosk_key *zosk_key_add(struct zosk *zosk, int w2, SDLKey sym, SDLKey symFn, SDLKey symShift){
+struct zosk_key *zosk_key_add(struct zosk *zosk, int w2, SDL_Keycode sym, SDL_Keycode symFn, SDL_Keycode symShift){
     struct zosk_key *key = g_new0(struct zosk_key, 1);
 
     key->x = zosk->x0 + (zosk->x2 * zosk->bw2 * 2) / 2;
@@ -144,7 +147,7 @@ struct zosk *zosk_init(SDL_Surface *screen, int flags, const char *text){
     zosk_key_add(zosk, 2, SDLK_2, SDLK_F2, SDLK_AT);
 	zosk_key_add(zosk, 2, SDLK_3, SDLK_F3, SDLK_HASH);
     zosk_key_add(zosk, 2, SDLK_4, SDLK_F4, SDLK_DOLLAR);
-    zosk_key_add(zosk, 2, SDLK_5, SDLK_F5, (SDLKey)'%');
+	zosk_key_add(zosk, 2, SDLK_5, SDLK_F5, (SDL_Keycode)'%');
     zosk_key_add(zosk, 2, SDLK_6, SDLK_F6, SDLK_CARET);
     zosk_key_add(zosk, 2, SDLK_7, SDLK_F7, SDLK_AMPERSAND);
     zosk_key_add(zosk, 2, SDLK_8, SDLK_F8, SDLK_ASTERISK);			   
@@ -153,13 +156,13 @@ struct zosk *zosk_init(SDL_Surface *screen, int flags, const char *text){
 
     zosk->x2 = 0;
 	zosk->y++;
-    zosk_key_add(zosk, 2, SDLK_q, (SDLKey)'~', SDLK_UNKNOWN);
+	zosk_key_add(zosk, 2, SDLK_q, (SDL_Keycode)'~', SDLK_UNKNOWN);
     zosk_key_add(zosk, 2, SDLK_w, SDLK_EXCLAIM, SDLK_UNKNOWN);
     zosk_key_add(zosk, 2, SDLK_e, SDLK_AT, SDLK_UNKNOWN);
     zosk_key_add(zosk, 2, SDLK_r, SDLK_HASH, SDLK_UNKNOWN);
 	zosk_key_add(zosk, 2, SDLK_t, SDLK_DOLLAR, SDLK_UNKNOWN);
-    zosk_key_add(zosk, 2, SDLK_y, (SDLKey)'%', SDLK_UNKNOWN);
-    zosk_key_add(zosk, 2, SDLK_u, (SDLKey)SDLK_CARET, SDLK_UNKNOWN);
+	zosk_key_add(zosk, 2, SDLK_y, (SDL_Keycode)'%', SDLK_UNKNOWN);
+	zosk_key_add(zosk, 2, SDLK_u, (SDL_Keycode)SDLK_CARET, SDLK_UNKNOWN);
 	zosk_key_add(zosk, 2, SDLK_i, SDLK_AMPERSAND, SDLK_UNKNOWN);
 	zosk_key_add(zosk, 2, SDLK_o, SDLK_ASTERISK, SDLK_UNKNOWN);
 	zosk_key_add(zosk, 2, SDLK_p, SDLK_UNKNOWN, SDLK_UNKNOWN);
@@ -198,7 +201,7 @@ struct zosk *zosk_init(SDL_Surface *screen, int flags, const char *text){
     zosk_key_add(zosk, 2, SDLK_LALT, SDLK_UNKNOWN, SDLK_UNKNOWN);
     zosk_key_add(zosk, 6, SDLK_SPACE, SDLK_UNKNOWN, SDLK_UNKNOWN);
 	zosk_key_add(zosk, 2, SDLK_QUESTION, SDLK_UNKNOWN, SDLK_UNKNOWN);
-    zosk_key_add(zosk, 2, SDLK_PERIOD, (SDLKey)'|', SDLK_UNKNOWN);
+	zosk_key_add(zosk, 2, SDLK_PERIOD, (SDL_Keycode)'|', SDLK_UNKNOWN);
 	zosk_key_add(zosk, 2, SDLK_SLASH, SDLK_BACKSLASH, SDLK_UNKNOWN);
     zosk_key_add(zosk, 3, SDLK_RETURN, SDLK_UNKNOWN, SDLK_UNKNOWN);
     return zosk;
@@ -402,7 +405,7 @@ void zosk_draw_top(struct zosk *zosk, struct zosk_key *key){
 		Bmask = 0x0000FF00;
 		Amask = 0x000000FF;
 	}
-	surface = SDL_AllocSurface(SDL_SWSURFACE, 10 + fw * strlen(c), 10 + fh, 32, Rmask, Gmask, Bmask, Amask);
+	surface = SDL_CreateRGBSurface(SDL_SWSURFACE, 10 + fw * strlen(c), 10 + fh, 32, Rmask, Gmask, Bmask, Amask);
 
 	SDL_FillRect(surface, NULL, SDL_MapRGBA(surface->format, 150, 0, 0, 255)); // opaque
 
@@ -511,9 +514,11 @@ int zosk_send(struct zosk *zosk){
 	ev.key.keysym.sym = key->sym;
 	if (zosk->fn->pressed && key->symFn != SDLK_UNKNOWN) ev.key.keysym.sym = key->symFn;
 	if (zosk->shift->pressed && key->symShift != SDLK_UNKNOWN) ev.key.keysym.sym = key->symShift;
+#ifdef Z_HAVE_SDL1
 	ev.key.keysym.unicode = 0;
-	ev.key.state = SDL_PRESSED;
 	ev.key.which = 0;
+#endif
+	ev.key.state = SDL_PRESSED;
 	SDL_PushEvent(&ev);
     //dbg("push %d\n", ev.key.keysym.sym);
 
